==> sso-common-2.3.47-sources.jar: cn/com/duiba/sso/api/domain/dto/AdminDto.java <==
package cn.com.duiba.sso.api.domain.dto;

import com.google.common.collect.Sets;

import java.io.Serializable;
import java.util.Date;
import java.util.Set;

/**
 * Created by liuyao on 2017/5/11.
 */
public class AdminDto implements Serializable {

    private static final long serialVersionUID = 4264258296954554274L;

    private Long id;

    private String name;

    private String account;

    private String email;//主邮箱

    private String mobile; //手机号

    private String dingUserId; //该用户在钉钉中的Id

    private Boolean modelAuthorize;//是否通过钉钉手机端授权

    private Date gmtCreate;

    private Date gmtModified;

    private Set<Long> systemIdSet = Sets.newHashSet();

    public String getDingUserId() {
        return dingUserId;
    }

    public void setDingUserId(String dingUserId) {
        this.dingUserId = dingUserId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public Set<Long> getSystemIdSet() {
        return systemIdSet;
    }

    public void setSystemIdSet(Set<Long> systemIdSet) {
        this.systemIdSet = systemIdSet;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public Boolean getModelAuthorize() {
        return modelAuthorize;
    }

    public void setModelAuthorize(Boolean modelAuthorize) {
        this.modelAuthorize = modelAuthorize;
    }
}

==> sso-common-2.3.61-sources.jar: cn/com/duiba/sso/api/domain/dto/AdminDto.java <==
package cn.com.duiba.sso.api.domain.dto;

import com.google.common.collect.Sets;

import java.io.Serializable;
import java.util.Date;
import java.util.Optional;
import java.util.Set;

/**
 * Created by liuyao on 2017/5/11.
 */
public class AdminDto implements Serializable {

    private static final long serialVersionUID = 4264258296954554274L;

    private Long id;

    private String name;

    private String account;

    private String email;//主邮箱

    private String mobile; //手机号

    private String dingUserId; //该用户在钉钉中的Id

    private Boolean modelAuthorize;//是否通过钉钉手机端授权

    private Date gmtCreate;

    private Date gmtModified;

    private Set<Long> systemIdSet = Sets.newHashSet();

    public String getDingUserId() {
        return dingUserId;
    }

    public void setDingUserId(String dingUserId) {
        this.dingUserId = dingUserId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public Set<Long> getSystemIdSet() {
        return systemIdSet;
    }

    public void setSystemIdSet(Set<Long> systemIdSet) {
        this.systemIdSet = systemIdSet;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public Boolean getModelAuthorize() {
        return Optional.ofNullable(modelAuthorize).orElse(false);
    }

    public void setModelAuthorize(Boolean modelAuthorize) {
        this.modelAuthorize = modelAuthorize;
    }
}
